@@ -5,6 +5,7 @@ import (
 	"path/filepath"
 	"strings"
 
+	"github.com/cli/cli/v2/internal/gh"
 	"github.com/cli/cli/v2/pkg/cmd/attestation/api"
 	"github.com/cli/cli/v2/pkg/cmd/attestation/artifact/oci"
 	"github.com/cli/cli/v2/pkg/cmd/attestation/io"
@@ -16,6 +17,7 @@ import (
 type Options struct {
 	ArtifactPath         string
 	BundlePath           string
+	Config               func() (gh.Config, error)
 	CustomTrustedRoot    string
 	DenySelfHostedRunner bool
 	DigestAlgorithm      string
@@ -27,6 +29,8 @@ type Options struct {
 	Repo                 string
 	SAN                  string
 	SANRegex             string
+	SignerRepo           string
+	SignerWorkflow       string
 	APIClient            api.Client
 	Logger               *io.Handler
 	OCIClient            oci.Client
@@ -51,12 +55,12 @@ func (opts *Options) SetPolicyFlags() {
 		// to Owner
 		opts.Owner = splitRepo[0]
 
-		if opts.SAN == "" && opts.SANRegex == "" {
+		if !isSignerIdentityProvided(opts) {
 			opts.SANRegex = expandToGitHubURL(opts.Repo)
 		}
 		return
 	}
-	if opts.SAN == "" && opts.SANRegex == "" {
+	if !isSignerIdentityProvided(opts) {
 		opts.SANRegex = expandToGitHubURL(opts.Owner)
 	}
 }
@@ -64,13 +68,14 @@ func (opts *Options) SetPolicyFlags() {
 // AreFlagsValid checks that the provided flag combination is valid
 // and returns an error otherwise
 func (opts *Options) AreFlagsValid() error {
-	// check that Repo is in the expected format if provided
-	if opts.Repo != "" {
-		// we expect the repo argument to be in the format <OWNER>/<REPO>
-		splitRepo := strings.Split(opts.Repo, "/")
-		if len(splitRepo) != 2 {
-			return fmt.Errorf("invalid value provided for repo: %s", opts.Repo)
-		}
+	// If provided, check that the Repo option is in the expected format <OWNER>/<REPO>
+	if opts.Repo != "" && !isProvidedRepoValid(opts.Repo) {
+		return fmt.Errorf("invalid value provided for repo: %s", opts.Repo)
+	}
+
+	// If provided, check that the SignerRepo option is in the expected format <OWNER>/<REPO>
+	if opts.SignerRepo != "" && !isProvidedRepoValid(opts.SignerRepo) {
+		return fmt.Errorf("invalid value provided for signer-repo: %s", opts.SignerRepo)
 	}
 
 	// Check that limit is between 1 and 1000
@@ -81,6 +86,13 @@ func (opts *Options) AreFlagsValid() error {
 	return nil
 }
 
-func expandToGitHubURL(ownerOrRepo string) string {
-	return fmt.Sprintf("^https://github.com/%s/", ownerOrRepo)
+// check if any of the signer identity flags have been provided
+func isSignerIdentityProvided(opts *Options) bool {
+	return opts.SAN != "" || opts.SANRegex != "" || opts.SignerRepo != "" || opts.SignerWorkflow != ""
+}
+
+func isProvidedRepoValid(repo string) bool {
+	// we expect a provided repository argument be in the format <OWNER>/<REPO>
+	splitRepo := strings.Split(repo, "/")
+	return len(splitRepo) == 2
 }
